@@ -148,7 +148,6 @@ sub get_next_WANNABUILD {
 	    my $pipe = $db->pipe_query(
                 ($dist_config->get('WANNA_BUILD_API') ? '--api '.$dist_config->get('WANNA_BUILD_API') : ''),
 		'--list=needs-build',
-		'--dist=' . $dist_name,
                 ($dist_config->get('WANNA_BUILD_MIN_AGE') ? '--min-age '.$dist_config->get('WANNA_BUILD_MIN_AGE') : ''),
                 );
 	    if (!$pipe) {
@@ -340,7 +339,6 @@ sub do_wanna_build {
         use YAML::Tiny;
         my $pipe = $db->pipe_query(
 	'--api '.$dist_config->get('WANNA_BUILD_API'),
-	'--dist=' . $dist_config->get('DIST_NAME'),
        	$pkgver);
         unless ($pipe) {
             $self->unblock_signals();
@@ -391,7 +389,6 @@ sub do_wanna_build {
     }
     my $pipe = $db->pipe_query(
 	'-v',
-	'--dist=' . $dist_config->get('DIST_NAME'),
        	$pkgver);
     if ($pipe) {
 	while( <$pipe> ) {
@@ -515,6 +512,7 @@ sub do_build {
 			'--apt-update',
 			'--no-apt-upgrade',
 			'--no-apt-distupgrade',
+			'--no-run-lintian',
 			'--batch',
 			"--stats-dir=" . $self->get_conf('HOME') . "/stats",
 			"--dist=" . $dist_config->get('DIST_NAME');
@@ -540,12 +538,13 @@ sub do_build {
     if ($dist_config->get('BUILD_DEP_RESOLVER') || $todo->{'build_dep_resolver'}) {
 	push @sbuild_args, '--build-dep-resolver=' . ($dist_config->get('BUILD_DEP_RESOLVER') || $todo->{'build_dep_resolver'});
     }
-    # Check if we need to build the arch:all.
-    if (defined($todo->{'arch_all'}) && $todo->{'arch_all'}) {
-	push @sbuild_args, '--arch-all';
+    if ($dist_config->get('BUILT_ARCHITECTURE')) {
+        if ($dist_config->get('BUILT_ARCHITECTURE') eq 'all') {
+	    push ( @sbuild_args, "--arch-all", "--no-arch-any" );
+        } else {
+            push ( @sbuild_args, "--no-arch-all", "--arch-any", "--arch=" . $dist_config->get('BUILT_ARCHITECTURE') );
+	}
     }
-    push ( @sbuild_args, "--arch=" . $dist_config->get('BUILT_ARCHITECTURE') )
-	if $dist_config->get('BUILT_ARCHITECTURE');
     push ( @sbuild_args, "--chroot=" . $dist_config->get('SBUILD_CHROOT') )
 	if $dist_config->get('SBUILD_CHROOT');
 
@@ -692,13 +691,17 @@ sub move_to_upload {
     $pkg_noepoch =~ s/_\d*:/_/;
 
     my $changes_name = $pkg_noepoch . '_' . $arch . '.changes';
+    my $upload_path = $self->get_conf('HOME') . '/' . $dist_config->get('DUPLOAD_LOCAL_QUEUE_DIR') . '/' . $pkg_noepoch . '_' . $arch . '.upload';
 
     $self->log("$pv is autosigned, moving to '$upload_dir'\n");
-    system sprintf('dcmd mv %s/build/%s %s/%s/',
-	$self->get_conf('HOME'),
-	$changes_name,
-	$self->get_conf('HOME'),
-	$dist_config->get('DUPLOAD_LOCAL_QUEUE_DIR'));
+    if ( -f $upload_path ) {
+        unlink( $upload_path );
+        $self->log("'$upload_path' removed.\n");
+    }
+    system(qw(dcmd mv --),
+        sprintf('%s/build/%s', $self->get_conf('HOME'), $changes_name),
+        sprintf('%s/%s/', $self->get_conf('HOME'), $dist_config->get('DUPLOAD_LOCAL_QUEUE_DIR'))
+    );
     $self->log("$pv moved to '$upload_dir'\n");
 }
 
@@ -716,7 +719,6 @@ sub handle_prevfailed {
     my $db = $self->get_db_handle($dist_config);
     my $pipe = $db->pipe_query(
 	'--info',
-       	'--dist=' . $dist_name,
        	$pkg);
     if (!$pipe) {
 	$self->log("Can't run wanna-build: $!\n");
